==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/cs_CZ.php <==
<?php
$lang['friendlyname'] = 'Spr&aacute;vce souborů';
$lang['permission'] = 'Použit&iacute; modulu Spr&aacute;vce souborů';
$lang['permissionadvanced'] = 'Roz&scaron;&iacute;řen&eacute; použit&iacute; modulu Spr&aacute;vce souborů';
$lang['moddescription'] = 'Spr&aacute;va souborů a adres&aacute;řů v cmsms sekci uploads';
$lang['installed'] = 'FileManager verze %s nainstalov&aacute;n';
$lang['postinstall'] = 'FileManager modul byl nainstalov&aacute;n';
$lang['uninstalled'] = 'FileManager modul odinstalov&aacute;n';
$lang['really_uninstall'] = 'Opravdu chcete odinstalovat modul FileManager?';
$lang['upgraded'] = 'FileManager modul aktualizov&aacute;n na verzi %s';
$lang['fileview'] = 'Zobrazen&iacute; souborů';
$lang['switchtofileview'] = 'Přepnout do zobrazen&iacute; souborů';
$lang['settings'] = 'Nastaven&iacute;';
$lang['savesettings'] = 'Uložit nastaven&iacute;';
$lang['filename'] = 'Jm&eacute;no souboru';
$lang['fileinfo'] = 'Informace o souboru';
$lang['fileowner'] = 'Vlastn&iacute;k souboru';
$lang['fileperms'] = 'Opr&aacute;vněn&iacute;';
$lang['filesize'] = 'Velikost';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Akce';
$lang['delete'] = 'Smazat';
$lang['notwritable'] = 'Pouze pro čten&iacute;';
$lang['filetoobig'] = 'je př&iacute;li&scaron; velk&yacute;. Nahr&aacute;v&aacute;n&iacute; bylo zru&scaron;eno.';
$lang['unknown'] = 'Nezn&aacute;m&yacute;';
$lang['fileoutsideuploads'] = 'Nem&aacute;te povolen&iacute; upravovat soubory mimo adres&aacute;ř uploads! (Vyžaduje Pokročil&aacute; opr&aacute;vněn&iacute; spr&aacute;vce souborů)';
$lang['writable'] = 'Zapisovateln&eacute;';
$lang['writeprotected'] = 'Ochrana proti z&aacute;pisu';
$lang['bytes'] = 'bajtů';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'sobory';
$lang['bytesin'] = 'bajtů v';
$lang['in'] = 'v';
$lang['file'] = 'soubor';
$lang['fileno'] = 'Soubor č.';
$lang['subdirs'] = 'podadres&aacute;ře';
$lang['subdir'] = 'podadres&aacute;ř';
$lang['and'] = 'a';
$lang['confirmsingledelete'] = 'Opravdu to chcete?';
$lang['confirmsingledirdelete'] = 'Jste si jisti, že m&aacute; b&yacute;t tento adres&aacute;ř smaz&aacute;n?';
$lang['dirtreedeletesuccess'] = 'Adres&aacute;ř včetne v&scaron;ech podsouborů byl smaz&aacute;n.';
$lang['dirtreedeletefail'] = 'Vyskytla se chyba při maz&aacute;n&iacute; tohoto adres&aacute;ře. Nějak&eacute; soubory již mohou b&yacute;t smaz&aacute;ny.';
$lang['singlefiledeletesuccess'] = 'Soubor byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['filedeletesuccess'] = 'byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['singlefiledeletefail'] = 'Nastala chyba při pokusu smazat soubor';
$lang['filedeletefail'] = 'nebyl smaz&aacute;n kvůli chybě';
$lang['singledirdeletesuccess'] = 'Adres&aacute;ř byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['singledirdeletefail'] = 'Nastala chyba při pokusu smazat adres&aacute;ř (je pr&aacute;zdn&yacute;?)';
$lang['deleteselected'] = 'Smazat označen&eacute; soubory';
$lang['confirmselected'] = 'Jste si jist?';
$lang['confirmdeleteselected'] = 'Opravdu chcete smazat označen&eacute; soubory?';
$lang['deleteselectedcancelled'] = 'Maz&aacute;n&iacute; označen&yacute;ch souborů zru&scaron;eno';
$lang['recursetext'] = 'Rekurze do podadres&aacute;řů';
$lang['nofilesselected'] = 'Ž&aacute;dn&eacute; soubory označeny';
$lang['moveselected'] = 'Přesunout označen&eacute; soubory';
$lang['copyselected'] = 'Kop&iacute;rovat označen&eacute; soubory';
$lang['selecttargetdir'] = 'Vyberte c&iacute;lov&yacute; adres&aacute;ř pro přesun/kop&iacute;rov&aacute;n&iacute;';
$lang['movedto'] = 'přesunuto do';
$lang['copiedto'] = 'zkop&iacute;rov&aacute;no do';
$lang['couldnotmove'] = 'nelze přesunout';
$lang['couldnotcopy'] = 'nelze kop&iacute;rovat';
$lang['rename'] = 'Přejmenovat';
$lang['newname'] = 'Nov&yacute; n&aacute;zev:';
$lang['renamesuccess'] = 'Soubor &uacute;spě&scaron;ně přejmenov&aacute;n';
$lang['renamefailure'] = 'Přejmenov&aacute;n&iacute; souboru selhalo';
$lang['renamecancelled'] = 'Přejmenov&aacute;n&iacute; zru&scaron;eno';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostatn&iacute;';
$lang['newpermissions'] = 'Nov&aacute; opr&aacute;vněn&iacute;:';
$lang['setpermissions'] = 'Nastavit opr&aacute;vněn&iacute;';
$lang['permissionstyle'] = 'Styl opr&aacute;vněn&iacute;';
$lang['rwxstyle'] = 'rwx styl';
$lang['755style'] = '755 styl';
$lang['quickmode'] = 'Rychl&yacute; chmod (jako 777)';
$lang['chmod'] = 'Změna opr&aacute;vněn&iacute;';
$lang['chmodselected'] = 'Změnit opr&aacute;vněn&iacute; na označen&yacute;ch souborech';
$lang['chmodsuccess'] = 'Opr&aacute;vněn&iacute; souboru &uacute;spě&scaron;ně změněno';
$lang['chmodfailure'] = 'Změna opr&aacute;vněn&iacute; souboru selhalo';
$lang['chmodcancelled'] = 'Změna opr&aacute;vněn&iacute; stornov&aacute;na';
$lang['dirchmodfailmulti'] = 'Změna opr&aacute;vněn&iacute; adres&aacute;ře selhala, přesto někter&eacute; jeho položky maj&iacute; nov&aacute; opr&aacute;vněn&iacute;.';
$lang['dirchmodsuccessmulti'] = 'Změna opr&aacute;vněn&iacute; adres&aacute;ře a jeho obsahu byla &uacute;spě&scaron;n&aacute;';
$lang['dirchmodsuccess'] = 'Změna opr&aacute;vněn&iacute; proběhla &uacute;spě&scaron;ně';
$lang['dirchmodfailure'] = 'Změna opr&aacute;vněn&iacute; se nezdařila';
$lang['dirnotemptyconfirm'] = 'Tento adres&aacute;ř nen&iacute; pr&aacute;zdn&yacute;. Jste si jist, že ho chcete smazat včetně v&scaron;ech podadres&aacute;řů a souborů?';
$lang['dirtreedeletecancelled'] = 'Maz&aacute;n&iacute; adres&aacute;ře bylo stornov&aacute;no.';
$lang['imsure'] = 'Jsem si jist';
$lang['cancel'] = 'Zru&scaron;it';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Nahr&aacute;t nov&yacute; soubor:';
$lang['unpackafterupload'] = 'Pokusit se soubor rozbalit po nahr&aacute;n&iacute;?';
$lang['uploadsuccess'] = 'Soubor nahr&aacute;n &uacute;spě&scaron;ně';
$lang['uploadfail'] = 'Nastala chyba při nahr&aacute;v&aacute;n&iacute; souboru';
$lang['unpacksuccess'] = 'Soubor byl &uacute;&scaron;pě&scaron;ně rozbalen';
$lang['unpackfail'] = 'Nastaly chyby během rozbalov&aacute;n&iacute; souboru:';
$lang['packfileopenfail'] = 'Nemohu rozbalit soubor (nepodporovan&yacute; form&aacute;t?)';
$lang['packfilewritefail'] = 'Nemohu otevř&iacute;t soubor &amp;s pro z&aacute;pis';
$lang['currentpath'] = 'Aktu&aacute;ln&iacute; adres&aacute;ř:';
$lang['newdirname'] = 'Vytvořit nov&yacute; adres&aacute;ř:';
$lang['newdirsuccess'] = 'Adres&aacute;ř byl &uacute;spě&scaron;ně vytvořen';
$lang['newdirfail'] = 'Nastala chyba během vytv&aacute;řen&iacute; adres&aacute;ře';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Velikost ikony';
$lang['smallicons'] = 'Mal&eacute; ikony';
$lang['largeicons'] = 'Velk&eacute; ikony';
$lang['thousanddelimiter'] = 'Oddělovač tis&iacute;ců';
$lang['none'] = 'Ž&aacute;dn&yacute;';
$lang['showthumbnails'] = 'Uk&aacute;zat n&aacute;hledy';
$lang['showthumbnailshelp'] = 'Povolen&iacute;m t&eacute;to volby se ve spr&aacute;vci souborů uk&aacute;ž&iacute; n&aacute;hledy obr&aacute;zků (pokud existuj&iacute;) a skryje vlastn&iacute; n&aacute;hledy. Při zak&aacute;z&aacute;n&iacute; se zobraz&iacute; v&scaron;echny soubory.';
$lang['uploadfilesto'] = 'Nahr&aacute;v&aacute;n&iacute; souborů do:';
$lang['uploadview'] = 'Nahr&aacute;t soubory';
$lang['uploadboxes'] = 'Počet nahr&aacute;vac&iacute;ch boxů';
$lang['nothinguploaded'] = 'Nic nebylo nahr&aacute;no';
$lang['unsupportedarchive'] = 'Nepodporovan&yacute; form&aacute;t archivu';
$lang['uploadmethod'] = 'Nahr&aacute;vac&iacute; metoda';
$lang['uploaderstandard'] = 'Standardn&iacute; html vkl&aacute;dac&iacute; metoda(dovoluje rozbalen&iacute;)';
$lang['enableadvanced'] = 'Povolit roz&scaron;&iacute;řen&yacute; m&oacute;d? (pokud povoleno)';
$lang['advancedhelp'] = 'Dovol&yacute; v&aacute;m př&iacute;stup do cel&eacute;ho cmsms, ne jenom do /upload/ (pokud dovoleno)';
$lang['showhiddenfileshelp'] = 'Efektivn&iacute; pouze se zapnut&yacute;m roz&scaron;&iacute;řen&yacute;m m&oacute;dem';
$lang['showhiddenfiles'] = 'Zobrazit skryt&eacute; soubory';
$lang['settingsconfirmsingledelete'] = 'Potvrdit smaz&aacute;n&iacute; samotn&eacute;ho souboru?';
$lang['settingssaved'] = 'Nastaven&iacute; uloženo';
$lang['help'] = '		<h3>Co děl&aacute; tento modul?</h3>
		<p>Tento modul poskytuje funkce spr&aacute;vy souborů</p>
		<h3>Jak se použ&iacute;v&aacute;?</h3>
		<p>Vyberte tento modul z menu v administraci.</p>';
$lang['utma'] = '156861353.4545864025444168000.1227726513.1235876853.1235894120.23';
$lang['utmz'] = '156861353.1235854022.19.6.utmccn=(referral)|utmcsr=miditower|utmcct=/cms/admin/listmodules.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/cs_CZ.php <==
<?php
$lang['friendlyname'] = 'Spr&aacute;vce souborů';
$lang['permission'] = 'Použit&iacute; modulu Spr&aacute;vce souborů';
$lang['permissionadvanced'] = 'Roz&scaron;&iacute;řen&eacute; použit&iacute; modulu Spr&aacute;vce souborů';
$lang['moddescription'] = 'Spr&aacute;va souborů a adres&aacute;řů v cmsms sekci uploads';
$lang['installed'] = 'FileManager verze %s nainstalov&aacute;n';
$lang['postinstall'] = 'FileManager modul byl nainstalov&aacute;n';
$lang['uninstalled'] = 'FileManager modul odinstalov&aacute;n';
$lang['really_uninstall'] = 'Opravdu chcete odinstalovat modul FileManager?';
$lang['upgraded'] = 'FileManager modul aktualizov&aacute;n na verzi %s';
$lang['fileview'] = 'Zobrazen&iacute; souborů';
$lang['switchtofileview'] = 'Přepnout do zobrazen&iacute; souborů';
$lang['settings'] = 'Nastaven&iacute;';
$lang['savesettings'] = 'Uložit nastaven&iacute;';
$lang['filename'] = 'Jm&eacute;no souboru';
$lang['fileinfo'] = 'Informace o souboru';
$lang['fileowner'] = 'Vlastn&iacute;k souboru';
$lang['fileperms'] = 'Opr&aacute;vněn&iacute;';
$lang['filesize'] = 'Velikost';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Akce';
$lang['delete'] = 'Smazat';
$lang['notwritable'] = 'Pouze pro čten&iacute;';
$lang['filetoobig'] = 'je př&iacute;li&scaron; velk&yacute;. Nahr&aacute;v&aacute;n&iacute; bylo zru&scaron;eno.';
$lang['unknown'] = 'Nezn&aacute;m&yacute;';
$lang['fileoutsideuploads'] = 'Nem&aacute;te povolen&iacute; upravovat soubory mimo adres&aacute;ř uploads! (Vyžaduje Pokročil&aacute; opr&aacute;vněn&iacute; spr&aacute;vce souborů)';
$lang['writable'] = 'Zapisovateln&eacute;';
$lang['writeprotected'] = 'Ochrana proti z&aacute;pisu';
$lang['bytes'] = 'bajtů';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'sobory';
$lang['bytesin'] = 'bajtů v';
$lang['in'] = 'v';
$lang['file'] = 'soubor';
$lang['fileno'] = 'Soubor č.';
$lang['subdirs'] = 'podadres&aacute;ře';
$lang['subdir'] = 'podadres&aacute;ř';
$lang['and'] = 'a';
$lang['confirmsingledelete'] = 'Opravdu to chcete?';
$lang['confirmsingledirdelete'] = 'Jste si jisti, že m&aacute; b&yacute;t tento adres&aacute;ř smaz&aacute;n?';
$lang['dirtreedeletesuccess'] = 'Adres&aacute;ř včetne v&scaron;ech podsouborů byl smaz&aacute;n.';
$lang['dirtreedeletefail'] = 'Vyskytla se chyba při maz&aacute;n&iacute; tohoto adres&aacute;ře. Nějak&eacute; soubory již mohou b&yacute;t smaz&aacute;ny.';
$lang['singlefiledeletesuccess'] = 'Soubor byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['filedeletesuccess'] = 'byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['singlefiledeletefail'] = 'Nastala chyba při pokusu smazat soubor';
$lang['filedeletefail'] = 'nebyl smaz&aacute;n kvůli chybě';
$lang['singledirdeletesuccess'] = 'Adres&aacute;ř byl &uacute;spě&scaron;ně smaz&aacute;n';
$lang['singledirdeletefail'] = 'Nastala chyba při pokusu smazat adres&aacute;ř (je pr&aacute;zdn&yacute;?)';
$lang['deleteselected'] = 'Smazat označen&eacute; soubory';
$lang['confirmselected'] = 'Jste si jist?';
$lang['confirmdeleteselected'] = 'Opravdu chcete smazat označen&eacute; soubory?';
$lang['deleteselectedcancelled'] = 'Maz&aacute;n&iacute; označen&yacute;ch souborů zru&scaron;eno';
$lang['recursetext'] = 'Rekurze do podadres&aacute;řů';
$lang['nofilesselected'] = 'Ž&aacute;dn&eacute; soubory označeny';
$lang['moveselected'] = 'Přesunout označen&eacute; soubory';
$lang['copyselected'] = 'Kop&iacute;rovat označen&eacute; soubory';
$lang['selecttargetdir'] = 'Vyberte c&iacute;lov&yacute; adres&aacute;ř pro přesun/kop&iacute;rov&aacute;n&iacute;';
$lang['movedto'] = 'přesunuto do';
$lang['copiedto'] = 'zkop&iacute;rov&aacute;no do';
$lang['couldnotmove'] = 'nelze přesunout';
$lang['couldnotcopy'] = 'nelze kop&iacute;rovat';
$lang['rename'] = 'Přejmenovat';
$lang['newname'] = 'Nov&yacute; n&aacute;zev:';
$lang['renamesuccess'] = 'Soubor &uacute;spě&scaron;ně přejmenov&aacute;n';
$lang['renamefailure'] = 'Přejmenov&aacute;n&iacute; souboru selhalo';
$lang['renamecancelled'] = 'Přejmenov&aacute;n&iacute; zru&scaron;eno';
$lang['owner'] = 'Vlastn&iacute;k';
$lang['group'] = 'Skupina';
$lang['others'] = 'Ostatn&iacute;';
$lang['newpermissions'] = 'Nov&aacute; opr&aacute;vněn&iacute;:';
$lang['setpermissions'] = 'Nastavit opr&aacute;vněn&iacute;';
$lang['permissionstyle'] = 'Styl opr&aacute;vněn&iacute;';
$lang['rwxstyle'] = 'rwx styl';
$lang['755style'] = '755 styl';
$lang['quickmode'] = 'Rychl&yacute; chmod (jako 777)';
$lang['chmod'] = 'Změna opr&aacute;vněn&iacute;';
$lang['chmodselected'] = 'Změnit opr&aacute;vněn&iacute; na označen&yacute;ch souborech';
$lang['chmodsuccess'] = 'Opr&aacute;vněn&iacute; souboru &uacute;spě&scaron;ně změněno';
$lang['chmodfailure'] = 'Změna opr&aacute;vněn&iacute; souboru selhalo';
$lang['chmodcancelled'] = 'Změna opr&aacute;vněn&iacute; stornov&aacute;na';
$lang['dirchmodfailmulti'] = 'Změna opr&aacute;vněn&iacute; adres&aacute;ře selhala, přesto někter&eacute; jeho položky maj&iacute; nov&aacute; opr&aacute;vněn&iacute;.';
$lang['dirchmodsuccessmulti'] = 'Změna opr&aacute;vněn&iacute; adres&aacute;ře a jeho obsahu byla &uacute;spě&scaron;n&aacute;';
$lang['dirchmodsuccess'] = 'Změna opr&aacute;vněn&iacute; proběhla &uacute;spě&scaron;ně';
$lang['dirchmodfailure'] = 'Změna opr&aacute;vněn&iacute; se nezdařila';
$lang['dirnotemptyconfirm'] = 'Tento adres&aacute;ř nen&iacute; pr&aacute;zdn&yacute;. Jste si jist, že ho chcete smazat včetně v&scaron;ech podadres&aacute;řů a souborů?';
$lang['dirtreedeletecancelled'] = 'Maz&aacute;n&iacute; adres&aacute;ře bylo stornov&aacute;no.';
$lang['imsure'] = 'Jsem si jist';
$lang['cancel'] = 'Zru&scaron;it';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Nahr&aacute;t nov&yacute; soubor:';
$lang['unpackafterupload'] = 'Pokusit se soubor rozbalit po nahr&aacute;n&iacute;?';
$lang['uploadsuccess'] = 'Soubor nahr&aacute;n &uacute;spě&scaron;ně';
$lang['uploadfail'] = 'Nastala chyba při nahr&aacute;v&aacute;n&iacute; souboru';
$lang['unpacksuccess'] = 'Soubor byl &uacute;&scaron;pě&scaron;ně rozbalen';
$lang['unpackfail'] = 'Nastaly chyby během rozbalov&aacute;n&iacute; souboru:';
$lang['packfileopenfail'] = 'Nemohu rozbalit soubor (nepodporovan&yacute; form&aacute;t?)';
$lang['packfilewritefail'] = 'Nemohu otevř&iacute;t soubor &amp;s pro z&aacute;pis';
$lang['currentpath'] = 'Aktu&aacute;ln&iacute; adres&aacute;ř:';
$lang['newdirname'] = 'Vytvořit nov&yacute; adres&aacute;ř:';
$lang['newdirsuccess'] = 'Adres&aacute;ř byl &uacute;spě&scaron;ně vytvořen';
$lang['newdirfail'] = 'Nastala chyba během vytv&aacute;řen&iacute; adres&aacute;ře';
$lang['invalidnewdir'] = 'Jm&eacute;no nov&eacute;ho adres&aacute;ře nesm&iacute; obsahovat znaky jako /, \ a &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Velikost ikony';
$lang['smallicons'] = 'Mal&eacute; ikony';
$lang['largeicons'] = 'Velk&eacute; ikony';
$lang['thousanddelimiter'] = 'Oddělovač tis&iacute;ců';
$lang['none'] = 'Ž&aacute;dn&yacute;';
$lang['space'] = 'mezera';
$lang['showthumbnails'] = 'Uk&aacute;zat n&aacute;hledy';
$lang['showthumbnailshelp'] = 'Povolen&iacute;m t&eacute;to volby se ve spr&aacute;vci souborů uk&aacute;ž&iacute; n&aacute;hledy obr&aacute;zků (pokud existuj&iacute;) a skryje vlastn&iacute; n&aacute;hledy. Při zak&aacute;z&aacute;n&iacute; se zobraz&iacute; v&scaron;echny soubory.';
$lang['uploadfilesto'] = 'Nahr&aacute;v&aacute;n&iacute; souborů do:';
$lang['uploadview'] = 'Nahr&aacute;t soubory';
$lang['uploadboxes'] = 'Počet nahr&aacute;vac&iacute;ch boxů';
$lang['nothinguploaded'] = 'Nic nebylo nahr&aacute;no';
$lang['unsupportedarchive'] = 'Nepodporovan&yacute; form&aacute;t archivu';
$lang['uploadmethod'] = 'Nahr&aacute;vac&iacute; metoda';
$lang['uploaderstandard'] = 'Standardn&iacute; html vkl&aacute;dac&iacute; metoda(dovoluje rozbalen&iacute;)';
$lang['enableadvanced'] = 'Povolit roz&scaron;&iacute;řen&yacute; m&oacute;d? (pokud povoleno)';
$lang['advancedhelp'] = 'Dovol&yacute; v&aacute;m př&iacute;stup do cel&eacute;ho cmsms, ne jenom do /upload/ (pokud dovoleno)';
$lang['showhiddenfileshelp'] = 'Efektivn&iacute; pouze se zapnut&yacute;m roz&scaron;&iacute;řen&yacute;m m&oacute;dem';
$lang['showhiddenfiles'] = 'Zobrazit skryt&eacute; soubory';
$lang['settingsconfirmsingledelete'] = 'Potvrdit smaz&aacute;n&iacute; samotn&eacute;ho souboru?';
$lang['settingssaved'] = 'Nastaven&iacute; uloženo';
$lang['help'] = '		<h3>Co děl&aacute; tento modul?</h3>
		<p>Tento modul poskytuje funkce spr&aacute;vy souborů</p>
		<h3>Jak se použ&iacute;v&aacute;?</h3>
		<p>Vyberte tento modul z menu v administraci.</p>';
$lang['utma'] = '156861353.503654010.1232181160.1240228642.1241432088.28';
$lang['utmz'] = '156861353.1239794723.26.6.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/users/peca/edit';
$lang['utmb'] = '156861353.1.10.1241432088';
$lang['utmc'] = '156861353';
?>
